@@ -26,7 +26,6 @@ module.
 from wsgiref import simple_server
 
 from oslo_serialization import jsonutils
-import six
 
 from keystonemiddleware import auth_token
 
@@ -34,7 +33,7 @@ from keystonemiddleware import auth_token
 def echo_app(environ, start_response):
     """A WSGI application that echoes the CGI environment back to the user."""
     start_response('200 OK', [('Content-Type', 'application/json')])
-    environment = dict((k, v) for k, v in six.iteritems(environ)
+    environment = dict((k, v) for k, v in environ.items()
                        if k.startswith('HTTP_X_'))
     yield jsonutils.dumps(environment)
 
@@ -44,7 +43,7 @@ class EchoService(object):
 
     def __init__(self):
         # hardcode any non-default configuration here
-        conf = {'auth_protocol': 'http', 'admin_token': 'ADMIN'}
+        conf = {'auth_protocol': 'http', 'admin_token': 'ADMIN'}  # nosec: B105
         app = auth_token.AuthProtocol(echo_app, conf)
         server = simple_server.make_server('', 8000, app)
         print('Serving on port 8000 (Ctrl+C to end)...')
