@@ -33,6 +33,7 @@ from keystoneauth1.loading import session as session_loading
 
 from keystonemiddleware._common import config
 from keystonemiddleware.auth_token import _cache
+from keystonemiddleware.auth_token import _request
 from keystonemiddleware.exceptions import ConfigurationError
 from keystonemiddleware.exceptions import KeystoneMiddlewareException
 from keystonemiddleware.i18n import _
@@ -246,7 +247,7 @@ class ClientSecretBasicAuthClient(AbstractAuthClient):
         the auth method 'client_secret_basic'.
         """
         req_data = {'token': access_token,
-                    'token_type_hint': 'access_token'}
+                    'token_type_hint': 'access_token'}  # nosec: B105
         auth = requests.auth.HTTPBasicAuth(self.client_id,
                                            self.client_secret)
         http_response = self.session.request(
@@ -279,7 +280,7 @@ class ClientSecretPostAuthClient(AbstractAuthClient):
             'client_id': self.client_id,
             'client_secret': self.client_secret,
             'token': access_token,
-            'token_type_hint': 'access_token'
+            'token_type_hint': 'access_token'  # nosec: B105
         }
         http_response = self.session.request(
             self.introspect_endpoint,
@@ -301,7 +302,7 @@ class TlsClientAuthClient(AbstractAuthClient):
         req_data = {
             'client_id': self.client_id,
             'token': access_token,
-            'token_type_hint': 'access_token'
+            'token_type_hint': 'access_token'  # nosec: B105
         }
         http_response = self.session.request(
             self.introspect_endpoint,
@@ -382,7 +383,7 @@ class PrivateKeyJwtAuthClient(AbstractAuthClient):
                 'urn:ietf:params:oauth:client-assertion-type:jwt-bearer',
             'client_assertion': client_assertion,
             'token': access_token,
-            'token_type_hint': 'access_token'
+            'token_type_hint': 'access_token'  # nosec: B105
         }
         http_response = self.session.request(
             self.introspect_endpoint,
@@ -442,7 +443,7 @@ class ClientSecretJwtAuthClient(AbstractAuthClient):
                 'urn:ietf:params:oauth:client-assertion-type:jwt-bearer',
             'client_assertion': client_assertion,
             'token': access_token,
-            'token_type_hint': 'access_token'
+            'token_type_hint': 'access_token'  # nosec: B105
         }
         http_response = self.session.request(
             self.introspect_endpoint,
@@ -534,7 +535,7 @@ class ExternalAuth2Protocol(object):
                                            **cache_kwargs)
         return _cache.TokenCache(self._log, **cache_kwargs)
 
-    @webob.dec.wsgify()
+    @webob.dec.wsgify(RequestClass=_request._AuthTokenRequest)
     def __call__(self, req):
         """Handle incoming request."""
         self.process_request(req)
@@ -545,8 +546,10 @@ class ExternalAuth2Protocol(object):
         """Process request.
 
         :param request: Incoming request
-        :type request: _request.AuthTokenRequest
+        :type request: _request._AuthTokenRequest
         """
+        request.remove_auth_headers()
+
         access_token = None
         if (request.authorization and
                 request.authorization.authtype == 'Bearer'):
